@@ -1,7 +1,7 @@
 """ GDB Python customization auto-loader for js shell """
 
 import os.path
-sys.path[0:0] = [os.path.join('/usr/obj/xulrunner-24.0/mozilla-release/js/src', 'gdb')]
+sys.path[0:0] = [os.path.join('/usr/obj/ports/xulrunner-24.7.0/mozilla-esr24/js/src', 'gdb')]
 
 import mozilla.autoload
 mozilla.autoload.register(gdb.current_objfile())
